@@ -11,6 +11,8 @@
 #include "eog-image-list.h"
 #include "libeog-marshal.h"
 
+#define DEBUG_IMAGE_LIST 0 
+
 struct  _EogIter {
 	/* age of the image list when the iterator was created */
 	unsigned int   age;
@@ -454,7 +456,7 @@ vfs_monitor_dir_cb (GnomeVFSMonitorHandle *handle,
 	EogImage *image = NULL;
 	GList *node=NULL;
 	gboolean found = FALSE;
-	
+
 	cleanup_dead_files (list);
 	
 	switch (event_type) {
@@ -570,21 +572,12 @@ static void
 add_regular (EogImageList *list, GnomeVFSURI *uri, GnomeVFSFileInfo *info)
 {
 	EogImage *image;
-	gboolean load_uri = FALSE;
 	
-	if ((info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_MIME_TYPE) > 0) {
-		if (is_supported_mime_type (info->mime_type)) {			
-			load_uri = TRUE;
-		}
-	}
-
-	if (load_uri) {		
-		image = eog_image_new_uri (uri);
+	image = eog_image_new_uri (uri);
 		
-		if (image != NULL) {
-			add_image_private (list, image, FALSE);
-			g_object_unref (image);
-		}
+	if (image != NULL) {
+		add_image_private (list, image, FALSE);
+		g_object_unref (image);
 	}
 }
 	
@@ -644,6 +637,18 @@ eog_image_list_add_uris (EogImageList *list, GList *uri_list)
 				continue;
 			
 			add_directory (list, uri, info);
+
+			/* If the file we explicitly requested wasn't 'found' when
+			 * scanning the directory then explicitly add it.
+			 */
+			if (NULL == g_list_find_custom (priv->store, initial_uri,
+							compare_uri_cb))
+			{
+				if (!get_uri_info (initial_uri, info))
+					continue;
+
+				add_regular (list, initial_uri, info);
+			}
 		}	
 		else if (info->type == GNOME_VFS_FILE_TYPE_REGULAR && 
 			 g_list_length (uri_list) > 1) {
@@ -746,6 +751,7 @@ eog_image_list_get_base_uri (EogImageList *list)
 void
 eog_image_list_print_debug (EogImageList *list)
 {
+#if DEBUG_IMAGE_LIST
 	GList *it;
 	EogImageListPrivate *priv;
 	int i = 1;
@@ -765,6 +771,7 @@ eog_image_list_print_debug (EogImageList *list)
 		
 		g_free (uri_str);
 	}
+#endif
 }
 
 void
